@@ -630,17 +630,6 @@ class SoftwarePropertiesGtk(SoftwareProperties,SimpleGtkbuilderApp):
     """Open the edit dialog if a channel was double clicked"""
     self.on_edit_clicked(treeview)
 
-  def on_treeview_sources_cursor_changed(self, treeview):
-    """Enable the buttons remove and edit if a channel is selected"""
-    sel = self.treeview_sources.get_selection()
-    (model, iter) = sel.get_selected()
-    if iter:
-        self.button_edit.set_sensitive(True)
-        self.button_remove.set_sensitive(True)
-    else:
-        self.button_edit.set_sensitive(False)
-        self.button_remove.set_sensitive(False)
-  
   def on_isv_source_toggled(self, cell_toggle, path, store):
     """Enable or disable the selected channel"""
     #FIXME cdroms need to disable the comps in the childs and sources
@@ -672,9 +661,9 @@ class SoftwarePropertiesGtk(SoftwareProperties,SimpleGtkbuilderApp):
       menu = Gtk.Menu()
       item_paste = Gtk.MenuItem(label=_("_Add key from paste data"))
       item_paste.connect("activate", self.on_auth_add_key_from_paste)
-      menu.add(item_paste)
-      menu.popup(None, None, None, 0, event.time)
+      menu.append(item_paste)
       menu.show_all()
+      menu.popup(None, None, None, None, event.button, event.time)
       return True
 
   def on_auth_add_key_from_paste(self, widget):
@@ -812,11 +801,12 @@ class SoftwarePropertiesGtk(SoftwareProperties,SimpleGtkbuilderApp):
      if self.button_edit.get_property("sensitive") == True:
          self.on_edit_clicked(treeview)
 
-  # FIXME:outstanding from merge
   def on_treeview_sources_cursor_changed(self, treeview):
     """set the sensitiveness of the edit and remove button
        corresponding to the selected channel"""
     sel = self.treeview_sources.get_selection()
+    if not sel:
+        return
     (model, iter) = sel.get_selected()
     if not iter:
         # No channel is selected, so disable edit and remove
