@@ -149,10 +149,6 @@ class SoftwarePropertiesKDE(SoftwareProperties):
   def init_release_upgrades(self):
     " setup the widgets that allow configuring the release upgrades "
     i = self.get_release_upgrades_policy()
-
-    # FIXME: hack for LP: #944876
-    i = (i + 1) % 3
-
     self.userinterface.combobox_release_upgrades.setCurrentIndex(i)
     kapp.connect(self.userinterface.combobox_release_upgrades, SIGNAL("currentIndexChanged(int)"), self.on_combobox_release_upgrades_changed)
 
@@ -399,10 +395,6 @@ class SoftwarePropertiesKDE(SoftwareProperties):
   def on_combobox_release_upgrades_changed(self, combobox):
     """ set the release upgrades policy """
     i = self.userinterface.combobox_release_upgrades.currentIndex()
-
-    # FIXME: hack for LP: #944876
-    i = (i - 1) % 3
-
     self.set_release_upgrades_policy(i)
 
   def on_combobox_server_changed(self, combobox):
@@ -603,8 +595,8 @@ class SoftwarePropertiesKDE(SoftwareProperties):
     if index != -1:
         value = self.combobox_interval_mapping[index]
         # Only write the key if it has changed
-        if not value == apt_pkg.Config.FindI(softwareproperties.CONF_MAP["autoupdate"]):
-            apt_pkg.Config.Set(softwareproperties.CONF_MAP["autoupdate"], str(value))
+        if not value == apt_pkg.config.find_i(softwareproperties.CONF_MAP["autoupdate"]):
+            apt_pkg.config.set(softwareproperties.CONF_MAP["autoupdate"], str(value))
             self.write_config()
 
   def on_auto_update_toggled(self):
@@ -728,23 +720,23 @@ class SoftwarePropertiesKDE(SoftwareProperties):
     '''Show a dialog that allows to add a repository located on a CDROM
        or DVD'''
     # testing
-    #apt_pkg.Config.Set("APT::CDROM::Rename","true")
+    #apt_pkg.config.set("APT::CDROM::Rename","true")
 
-    saved_entry = apt_pkg.Config.Find("Dir::Etc::sourcelist")
+    saved_entry = apt_pkg.config.find("Dir::Etc::sourcelist")
     tmp = tempfile.NamedTemporaryFile()
-    apt_pkg.Config.Set("Dir::Etc::sourcelist",tmp.name)
+    apt_pkg.config.set("Dir::Etc::sourcelist",tmp.name)
     progress = CdromProgress(self.datadir, self, kapp)
-    cdrom = apt_pkg.GetCdrom()
+    cdrom = apt_pkg.Cdrom()
     # if nothing was found just return
     try:
-      res = cdrom.Add(progress)
+      res = cdrom.add(progress)
     except SystemError, msg:
       title = _("CD Error")
       text = _("<big><b>Error scanning the CD</b></big>\n\n%s")%msg
       KMessageBox.sorry(self.userinterface, utf8(text), utf8(title))
       return
     finally:
-      apt_pkg.Config.Set("Dir::Etc::sourcelist",saved_entry)
+      apt_pkg.config.set("Dir::Etc::sourcelist",saved_entry)
       progress.close()
 
     if res == False:
@@ -754,7 +746,7 @@ class SoftwarePropertiesKDE(SoftwareProperties):
     for x in open(tmp.name):
       line = x
     if line != "":
-      full_path = "%s%s" % (apt_pkg.Config.FindDir("Dir::Etc"),saved_entry)
+      full_path = "%s%s" % (apt_pkg.config.find_dir("Dir::Etc"),saved_entry)
       # insert cdrom source first, so that it has precedence over network sources
       self.sourceslist.list.insert(0, SourceEntry(line,full_path))
       self.set_modified_sourceslist()
